@@ -7,7 +7,12 @@ from django.utils.deprecation import MiddlewareMixin
 from django_boost.http import STATUS_MESSAGES
 from django_boost.http.response import (HttpExceptionBase,
                                         HttpRedirectExceptionBase)
-from django_boost.middleware.html import SpaceLessMiddleware
+from .html import SpaceLessMiddleware
+
+
+__all__ = ['SpaceLessMiddleware',
+           'RedirectCorrectHostnameMiddleware',
+           'HttpStatusCodeExceptionMiddleware']
 
 
 class RedirectCorrectHostnameMiddleware(MiddlewareMixin):
@@ -37,7 +42,9 @@ class RedirectCorrectHostnameMiddleware(MiddlewareMixin):
 
     This is useful when migrating domains
 
-    Originally it should be done with server software such as nginx and apache, but it is useful when the setting is troublesome or when using services such as heroku
+    Originally it should be done with server software such as nginx and apache,
+
+    but it is useful when the setting is troublesome or when using services such as heroku.
     """
 
     conditions = not settings.DEBUG and hasattr(settings, 'CORRECT_HOST')
@@ -74,7 +81,6 @@ class HttpStatusCodeExceptionMiddleware(MiddlewareMixin):
 
     This Middleware is required when using the :doc:`http_status_code_exceptions`.
 
-
     """
 
     def get_template_from_status_code(self, status_code, request=None):
